-- Top level of the example design in VHDL
library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_arith.all;
use IEEE.std_logic_unsigned.all;

entity top is 
   port( SRAM_DATA: inout  std_logic_vector(7 downto 0); 
         WR_addr :  in  std_logic_vector(6 downto 0); 
         RD_addr :  out std_logic_vector (6 downto 0);
         WR_EN   : in      std_logic;
         RD_EN   : in      std_logic;
         Aclr     : in      std_logic;
         WClock  : in      std_logic;
         RClock  : in      std_logic) ;
end top;

architecture behave of top is

component memory
port( Data : in      std_logic_vector(7 downto 0); 
      Q    : out     std_logic_vector(7 downto 0); 
      WAddress : in  std_logic_vector(6 downto 0); 
      RAddress : in  std_logic_vector(6 downto 0);
      WE       : in      std_logic;
      RE       : in      std_logic;
      WClock   : in      std_logic;
      RClock   : in      std_logic) ;
end component; 

signal DIR_CON : std_logic;
signal WDATA, RDATA: std_logic_vector(7 downto 0); 
signal RADDR: std_logic_vector(6 downto 0);

begin

direction: Process (WR_EN, RD_EN)
begin 
if (WR_EN = '0') then
  DIR_CON <= '0';
elsif (RD_EN = '0') then
  DIR_CON <= '1';
else
  DIR_CON <= '0';
end if;
end process;


write: process (Wclock, DIR_CON)
begin
 if (WClock'event and WClock = '1') then
  --begin 
  if (DIR_CON = '0') then
    WDATA <= SRAM_DATA;
  end if;
  --end
  end if;
end process;

read: process (RClock, DIR_CON)
begin 
 if (RClock'event and RClock = '1') then
   if (DIR_CON = '1') then
     SRAM_DATA <= RDATA;
   else
    SRAM_DATA <= "ZZZZZZZZ"; 
   end if;
  end if;
end process;


address: process (RD_EN, Aclr, Rclock)
begin 
if (Aclr = '0') then 
  RADDR <= (others => '0');
elsif (RClock'event and RClock = '1') then
  if (RD_EN = '0') then 
  RADDR <= RADDR + '1';
  end if;
end if;
 
end process;

RD_addr <= RADDR;

U1: memory 
    port map(Data     => WDATA, 
             Q        => RDATA, 
             WAddress => WR_addr, 
             RAddress => RADDR,
             WE       => WR_EN,
             RE       => RD_EN,
             WClock   => WClock,
             RClock   => RClock );



end behave;
